# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           maven2-plugin-shade
Version:        1.0
Release:	8%{?dist}
Epoch:          0
Summary:        Maven Shade Plugin
License:        ASL 2.0
Group:          Development/Java
URL:            http://maven.apache.org/

# svn export https://svn.apache.org/repos/asf/maven/plugins/tags/maven-shade-plugin-1.0 maven2-plugin-shade
# tar czf maven2-shade-plugin-1.0-src.tar.gz maven2-plugin-shade

Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}-jpp-depmap.xml
Patch0:         %{name}-pom.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-site
BuildRequires:  maven2-plugin-plugin
BuildRequires:  maven2-plugin-surefire 
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  apache-commons-parent
BuildRequires:  plexus-archiver >= 1.0-0.1.a7
BuildRequires:  plexus-maven-plugin >= 1.3.5
BuildRequires:  plexus-cdc < 0:1.0-0.3.a11
BuildRequires:  qdox >= 1.5
BuildRequires:  tomcat5
BuildRequires:  tomcat5-servlet-2.4-api
BuildRequires:  excalibur-avalon-logkit
BuildRequires:  excalibur-avalon-framework

Requires:       java >= 0:1.6.0
Requires:       maven2 >= 0:2.0.8
Requires:       plexus-archiver >= 1.0-0.1.a7

Requires(post):   jpackage-utils >= 0:1.7.5
Requires(postun): jpackage-utils >= 0:1.7.5

BuildArch:      noarch

%description
This plugin provides the capability to package the artifact
in an uber-jar, including its dependencies and to shade - 
i.e. rename - the packages of some of the dependencies.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{name}
%patch0 -b .sav0

%build

export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL

mvn-jpp \
    -e \
    -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
    -Dmaven2.jpp.depmap.file=%{SOURCE1} \
    -Dmaven.test.skip=true \
    install javadoc:javadoc

%install
rm -rf $RPM_BUILD_ROOT
# jars/poms
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms

# Copy file and create unversioned symlink
install -m 644 target/maven-shade-plugin-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
ln -s %{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar

# Copy pom
install -m 644 pom.xml $RPM_BUILD_ROOT/%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap org.apache.maven.plugins maven-shade-plugin %{version} JPP %{name}

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%{_javadir}/*
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(-,root,root,-)
%doc %{_javadocdir}/*

%changelog
* Fri Dec 03 2010 Ralph Apel <r.apel at r-apel.de> - 1.0-8
- Fix pom from asm to org.objectweb.asm groupId

* Sat Jan 09 2010 Will Tatam <will.tatam@red61.com> 1.0-7
- Auto rebuild for JPackage 6 in centos5 mock

* Wed Sep 02 2009 Ralph Apel <r.apel at r-apel.de> - 1.0-6
- Fix pom file naming

* Wed Sep 02 2009 Ralph Apel <r.apel at r-apel.de> - 1.0-5
- Add post and postun for depmap frags

* Wed May 20 2009 Fernando Nasser <fnasser@redhat.com> - 1.0-4
- Fix license
- Fix comment for source creation

* Mon Apr 20 2009 Yong Yang <yyang@redhat.com> - 1.0-3
- Rebuild with plexus-cdc alpha 10

* Fri Apr 17 2009 Yong Yang <yyang@redhat.com> - 1.0-2
- Add qdox and other BRs
- Add qdox jpp-depmap
- rebuild with maven2-2.0.8 built in non-bootstrap mode

* Thu Mar 05 2009 Yong Yang <yyang@redhat.com> - 1.0-1
- Imported from dbhole's maven2 2.0.8 packages

* Tue Mar 11 2008 Deepak Bhole <dbhole@redhat.com> - 1.0-0jpp.1
- Initial build
